pub struct EnumTypeValueVariant {
pub name: String,
pub value: Option<TypeValue>,
pub doc_comment: Option<String>,
pub attributes: Vec<Attribute>,
}Fields
name: Stringvalue: Option<TypeValue>If this variant has a value, this will be the type of that value otherwise its just a unit variant
doc_comment: Option<String>attributes: Vec<Attribute>Trait Implementations
Sourceimpl Clone for EnumTypeValueVariant
impl Clone for EnumTypeValueVariant
Sourcefn clone(&self) -> EnumTypeValueVariant
fn clone(&self) -> EnumTypeValueVariant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnumTypeValueVariant
impl Debug for EnumTypeValueVariant