pub struct MethodCall {
pub origin: MethodCallQuery,
pub args: Vec<Value>,
pub in_item_id: String,
}Fields
origin: MethodCallQueryThe query that produced this method call. This won’t always be your own query, as certain situations will cause one to be automatically generated. For instance, if you make a method call query one of the arguments to it can be another method call.
args: Vec<Value>in_item_id: StringTrait Implementations
Sourceimpl Clone for MethodCall
impl Clone for MethodCall
Sourcefn clone(&self) -> MethodCall
fn clone(&self) -> MethodCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MethodCall
impl Debug for MethodCall