MethodCallQuery

Struct MethodCallQuery 

pub struct MethodCallQuery {
    pub parent: Option<Box<MethodCallQuery>>,
    pub location: Location,
}
A query for method calls matching a specific path. This can be used, for example, to look for axum routes

Fields

parent: Option<Box<MethodCallQuery>>

If specified, this requires this method call to originate from a prior parent method call. For instance with the given source:

my_var.globals().set("something", 1).set("something_else", 2);

By setting parent to the method call query of globals, we can enforce that the set call is in a chain of globals and not a set on some other table.

location: Location

The path to the module this method call sits in.